aboutsummaryrefslogtreecommitdiffstats
path: root/tests/src
diff options
context:
space:
mode:
Diffstat (limited to 'tests/src')
-rw-r--r--tests/src/com/android/inputmethod/latin/BinaryDictionaryDecayingTests.java17
-rw-r--r--tests/src/com/android/inputmethod/latin/makedict/BinaryDictDecoderEncoderTests.java35
-rw-r--r--tests/src/com/android/inputmethod/latin/makedict/SparseTableTests.java107
3 files changed, 103 insertions, 56 deletions
diff --git a/tests/src/com/android/inputmethod/latin/makedict/BinaryDictDecoderEncoderTests.java b/tests/src/com/android/inputmethod/latin/makedict/BinaryDictDecoderEncoderTests.java
index a4d94262f..0cf4ef9f1 100644
--- a/tests/src/com/android/inputmethod/latin/makedict/BinaryDictDecoderEncoderTests.java
+++ b/tests/src/com/android/inputmethod/latin/makedict/BinaryDictDecoderEncoderTests.java
@@ -104,7 +104,9 @@ public class BinaryDictDecoderEncoderTests extends AndroidTestCase {
}
sStarBigrams.put(0, new ArrayList<Integer>());
- for (int i = 1; i < sWords.size(); ++i) {
+ // MAX - 1 because we added one above already
+ final int maxBigrams = Math.min(sWords.size(), FormatSpec.MAX_BIGRAMS_IN_A_PTNODE - 1);
+ for (int i = 1; i < maxBigrams; ++i) {
sStarBigrams.get(0).add(i);
}
@@ -544,8 +546,7 @@ public class BinaryDictDecoderEncoderTests extends AndroidTestCase {
}
private long checkGetTerminalPosition(final DictDecoder dictDecoder, final String word,
- int index, boolean contained) {
- final int expectedFrequency = (UNIGRAM_FREQ + index) % 255;
+ final boolean contained) {
long diff = -1;
int position = -1;
try {
@@ -603,7 +604,7 @@ public class BinaryDictDecoderEncoderTests extends AndroidTestCase {
// Test a word that is contained within the dictionary.
long sum = 0;
for (int i = 0; i < sWords.size(); ++i) {
- final long time = checkGetTerminalPosition(dictDecoder, sWords.get(i), i, true);
+ final long time = checkGetTerminalPosition(dictDecoder, sWords.get(i), true);
sum += time == -1 ? 0 : time;
}
Log.d(TAG, "per search : " + (((double)sum) / sWords.size() / 1000000) + " : " + message
@@ -616,11 +617,11 @@ public class BinaryDictDecoderEncoderTests extends AndroidTestCase {
for (int i = 0; i < 1000; ++i) {
final String word = CodePointUtils.generateWord(random, codePointSet);
if (sWords.indexOf(word) != -1) continue;
- checkGetTerminalPosition(dictDecoder, word, i, false);
+ checkGetTerminalPosition(dictDecoder, word, false);
}
}
- private void runGetTerminalPositionTests(final ArrayList<String> results, final int bufferType,
+ private void runGetTerminalPositionTests(final int bufferType,
final FormatOptions formatOptions) {
runGetTerminalPosition(sWords, sEmptyBigrams, bufferType, formatOptions, "unigram");
}
@@ -628,17 +629,17 @@ public class BinaryDictDecoderEncoderTests extends AndroidTestCase {
public void testGetTerminalPosition() {
final ArrayList<String> results = CollectionUtils.newArrayList();
- runGetTerminalPositionTests(results, USE_BYTE_ARRAY, VERSION2);
- runGetTerminalPositionTests(results, USE_BYTE_ARRAY, VERSION3_WITHOUT_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_ARRAY, VERSION3_WITH_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_ARRAY, VERSION4_WITHOUT_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_ARRAY, VERSION4_WITH_DYNAMIC_UPDATE);
-
- runGetTerminalPositionTests(results, USE_BYTE_BUFFER, VERSION2);
- runGetTerminalPositionTests(results, USE_BYTE_BUFFER, VERSION3_WITHOUT_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_BUFFER, VERSION3_WITH_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_BUFFER, VERSION4_WITHOUT_DYNAMIC_UPDATE);
- runGetTerminalPositionTests(results, USE_BYTE_BUFFER, VERSION4_WITH_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_ARRAY, VERSION2);
+ runGetTerminalPositionTests(USE_BYTE_ARRAY, VERSION3_WITHOUT_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_ARRAY, VERSION3_WITH_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_ARRAY, VERSION4_WITHOUT_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_ARRAY, VERSION4_WITH_DYNAMIC_UPDATE);
+
+ runGetTerminalPositionTests(USE_BYTE_BUFFER, VERSION2);
+ runGetTerminalPositionTests(USE_BYTE_BUFFER, VERSION3_WITHOUT_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_BUFFER, VERSION3_WITH_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_BUFFER, VERSION4_WITHOUT_DYNAMIC_UPDATE);
+ runGetTerminalPositionTests(USE_BYTE_BUFFER, VERSION4_WITH_DYNAMIC_UPDATE);
for (final String result : results) {
Log.d(TAG, result);
diff --git a/tests/src/com/android/inputmethod/latin/makedict/SparseTableTests.java b/tests/src/com/android/inputmethod/latin/makedict/SparseTableTests.java
index 132483d5e..aeb8552bd 100644
--- a/tests/src/com/android/inputmethod/latin/makedict/SparseTableTests.java
+++ b/tests/src/com/android/inputmethod/latin/makedict/SparseTableTests.java
@@ -21,10 +21,8 @@ import android.test.suitebuilder.annotation.LargeTest;
import android.util.Log;
import java.io.File;
-import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
-import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Random;
@@ -36,9 +34,6 @@ import java.util.Random;
public class SparseTableTests extends AndroidTestCase {
private static final String TAG = SparseTableTests.class.getSimpleName();
- private static final int[] SMALL_INDEX = { SparseTable.NOT_EXIST, 0 };
- private static final int[] BIG_INDEX = { SparseTable.NOT_EXIST, 1, 2, 3, 4, 5, 6, 7};
-
private final Random mRandom;
private final ArrayList<Integer> mRandomIndex;
@@ -59,32 +54,21 @@ public class SparseTableTests extends AndroidTestCase {
}
}
- public void testInitializeWithArray() {
- final SparseTable table = new SparseTable(SMALL_INDEX, BIG_INDEX, BLOCK_SIZE);
- for (int i = 0; i < 8; ++i) {
- assertEquals(SparseTable.NOT_EXIST, table.get(i));
- }
- assertEquals(SparseTable.NOT_EXIST, table.get(8));
- for (int i = 9; i < 16; ++i) {
- assertEquals(i - 8, table.get(i));
- }
- }
-
public void testSet() {
- final SparseTable table = new SparseTable(16, BLOCK_SIZE);
- table.set(3, 6);
- table.set(8, 16);
+ final SparseTable table = new SparseTable(16, BLOCK_SIZE, 1);
+ table.set(0, 3, 6);
+ table.set(0, 8, 16);
for (int i = 0; i < 16; ++i) {
if (i == 3 || i == 8) {
- assertEquals(i * 2, table.get(i));
+ assertEquals(i * 2, table.get(0, i));
} else {
- assertEquals(SparseTable.NOT_EXIST, table.get(i));
+ assertEquals(SparseTable.NOT_EXIST, table.get(0, i));
}
}
}
private void generateRandomIndex(final int size, final int prop) {
- for (int i = 0; i < DEFAULT_SIZE; ++i) {
+ for (int i = 0; i < size; ++i) {
if (mRandom.nextInt(100) < prop) {
mRandomIndex.set(i, mRandom.nextInt());
} else {
@@ -94,11 +78,11 @@ public class SparseTableTests extends AndroidTestCase {
}
private void runTestRandomSet() {
- final SparseTable table = new SparseTable(DEFAULT_SIZE, BLOCK_SIZE);
+ final SparseTable table = new SparseTable(DEFAULT_SIZE, BLOCK_SIZE, 1);
int elementCount = 0;
for (int i = 0; i < DEFAULT_SIZE; ++i) {
if (mRandomIndex.get(i) != SparseTable.NOT_EXIST) {
- table.set(i, mRandomIndex.get(i));
+ table.set(0, i, mRandomIndex.get(i));
elementCount++;
}
}
@@ -107,29 +91,24 @@ public class SparseTableTests extends AndroidTestCase {
+ table.getContentTableSize());
Log.d(TAG, "the table has " + elementCount + " elements");
for (int i = 0; i < DEFAULT_SIZE; ++i) {
- assertEquals(table.get(i), (int)mRandomIndex.get(i));
+ assertEquals(table.get(0, i), (int)mRandomIndex.get(i));
}
// flush and reload
OutputStream lookupOutStream = null;
OutputStream contentOutStream = null;
- InputStream lookupInStream = null;
- InputStream contentInStream = null;
try {
final File lookupIndexFile = File.createTempFile("testRandomSet", ".small");
final File contentFile = File.createTempFile("testRandomSet", ".big");
lookupOutStream = new FileOutputStream(lookupIndexFile);
contentOutStream = new FileOutputStream(contentFile);
- table.write(lookupOutStream, contentOutStream);
- lookupInStream = new FileInputStream(lookupIndexFile);
- contentInStream = new FileInputStream(contentFile);
- final byte[] lookupArray = new byte[(int) lookupIndexFile.length()];
- final byte[] contentArray = new byte[(int) contentFile.length()];
- lookupInStream.read(lookupArray);
- contentInStream.read(contentArray);
- final SparseTable newTable = new SparseTable(lookupArray, contentArray, BLOCK_SIZE);
+ table.write(lookupOutStream, new OutputStream[] { contentOutStream });
+ lookupOutStream.flush();
+ contentOutStream.flush();
+ final SparseTable newTable = SparseTable.readFromFiles(lookupIndexFile,
+ new File[] { contentFile }, BLOCK_SIZE);
for (int i = 0; i < DEFAULT_SIZE; ++i) {
- assertEquals(table.get(i), newTable.get(i));
+ assertEquals(table.get(0, i), newTable.get(0, i));
}
} catch (IOException e) {
Log.d(TAG, "IOException while flushing and realoding", e);
@@ -157,4 +136,60 @@ public class SparseTableTests extends AndroidTestCase {
runTestRandomSet();
}
}
+
+ public void testMultipleContents() {
+ final int numOfContents = 5;
+ generateRandomIndex(DEFAULT_SIZE, 20);
+ final SparseTable table = new SparseTable(DEFAULT_SIZE, BLOCK_SIZE, numOfContents);
+ for (int i = 0; i < mRandomIndex.size(); ++i) {
+ if (mRandomIndex.get(i) != SparseTable.NOT_EXIST) {
+ for (int j = 0; j < numOfContents; ++j) {
+ table.set(j, i, mRandomIndex.get(i));
+ }
+ }
+ }
+
+ OutputStream lookupOutStream = null;
+ OutputStream[] contentsOutStream = new OutputStream[numOfContents];
+ try {
+ final File lookupIndexFile = File.createTempFile("testMultipleContents", "small");
+ lookupOutStream = new FileOutputStream(lookupIndexFile);
+ final File[] contentFiles = new File[numOfContents];
+ for (int i = 0; i < numOfContents; ++i) {
+ contentFiles[i] = File.createTempFile("testMultipleContents", "big" + i);
+ contentsOutStream[i] = new FileOutputStream(contentFiles[i]);
+ }
+ table.write(lookupOutStream, contentsOutStream);
+ lookupOutStream.flush();
+ for (int i = 0; i < numOfContents; ++i) {
+ contentsOutStream[i].flush();
+ }
+ final SparseTable newTable = SparseTable.readFromFiles(lookupIndexFile, contentFiles,
+ BLOCK_SIZE);
+ for (int i = 0; i < numOfContents; ++i) {
+ for (int j = 0; j < DEFAULT_SIZE; ++j) {
+ assertEquals(table.get(i, j), newTable.get(i, j));
+ }
+ }
+ } catch (IOException e) {
+ Log.d(TAG, "IOException while flushing and reloading", e);
+ } finally {
+ if (lookupOutStream != null) {
+ try {
+ lookupOutStream.close();
+ } catch (IOException e) {
+ Log.d(TAG, "IOException while closing the stream", e);
+ }
+ }
+ for (int i = 0; i < numOfContents; ++i) {
+ if (contentsOutStream[i] != null) {
+ try {
+ contentsOutStream[i].close();
+ } catch (IOException e) {
+ Log.d(TAG, "IOException while closing the stream.", e);
+ }
+ }
+ }
+ }
+ }
}
diff --git a/tests/src/com/android/inputmethod/latin/BinaryDictionaryDecayingTests.java b/tests/src/com/android/inputmethod/latin/BinaryDictionaryDecayingTests.java
index cf85d97a0..b2d31c21f 100644
--- a/tests/src/com/android/inputmethod/latin/BinaryDictionaryDecayingTests.java
+++ b/tests/src/com/android/inputmethod/latin/BinaryDictionaryDecayingTests.java
@@ -32,6 +32,11 @@ public class BinaryDictionaryDecayingTests extends AndroidTestCase {
private static final String TEST_DICT_FILE_EXTENSION = ".testDict";
private static final String TEST_LOCALE = "test";
+ // Note that these are corresponding definitions in native code in
+ // latinime::DynamicPatriciaTriePolicy.
+ private static final String SET_NEEDS_TO_DECAY_FOR_TESTING_KEY =
+ "SET_NEEDS_TO_DECAY_FOR_TESTING";
+
private static final int DUMMY_PROBABILITY = 0;
@Override
@@ -45,14 +50,20 @@ public class BinaryDictionaryDecayingTests extends AndroidTestCase {
}
private void forcePassingShortTime(final BinaryDictionary binaryDictionary) {
- binaryDictionary.flushWithGC();
+ // Entries having low probability would be suppressed once in 2 GCs.
+ final int count = 2;
+ for (int i = 0; i < count; i++) {
+ binaryDictionary.getPropertyForTests(SET_NEEDS_TO_DECAY_FOR_TESTING_KEY);
+ binaryDictionary.flushWithGC();
+ }
}
private void forcePassingLongTime(final BinaryDictionary binaryDictionary) {
// Currently, probabilities are decayed when GC is run. All entries that have never been
- // typed in 32 GCs are removed.
- final int count = 32;
+ // typed in 128 GCs would be removed.
+ final int count = 128;
for (int i = 0; i < count; i++) {
+ binaryDictionary.getPropertyForTests(SET_NEEDS_TO_DECAY_FOR_TESTING_KEY);
binaryDictionary.flushWithGC();
}
}